Module rayon

Module rayon 

rayon-based parallel iterator types for hash maps. You will rarely need to interact with it directly unless you have need to name one of the iterator types.

Structs

IntoParIter
Parallel iterator over entries of a consumed map.
ParDrain
Parallel draining iterator over entries of a map.
ParIter
Parallel iterator over shared references to entries in a map.
ParIterMut
Parallel iterator over mutable references to entries in a map.
ParKeys
Parallel iterator over shared references to keys in a map.
ParValues
Parallel iterator over shared references to values in a map.
ParValuesMut
Parallel iterator over mutable references to values in a map.