Skip to main content Module hash_set Copy item path Source pub use super::HashSet ;rayon rayon -based parallel iterator types for hash sets.
You will rarely need to interact with it directly unless you have need
to name one of the iterator types.Difference A lazy iterator producing elements in the difference of HashSets. Drain A draining iterator over the items of a HashSet. ExtractIf A draining iterator over entries of a HashSet which don’t satisfy the predicate f. Intersection A lazy iterator producing elements in the intersection of HashSets. IntoIter An owning iterator over the items of a HashSet. Iter An iterator over the items of a HashSet. OccupiedEntry A view into an occupied entry in a HashSet.
It is part of the Entry enum. SymmetricDifference A lazy iterator producing elements in the symmetric difference of HashSets. Union A lazy iterator producing elements in the union of HashSets. VacantEntry A view into a vacant entry in a HashSet.
It is part of the Entry enum. Entry A view into a single entry in a set, which may either be vacant or occupied.