Module small_map

Module small_map 

Enums

SmallHashMap
A hash map optimized for small sizes, with a small size optimization for up to N entries and then a vector for up to M and then finally falling back to a real hash map after M.