SmallHashMap

Enum SmallHashMap 

pub enum SmallHashMap<K: Eq + Hash, V, const N: usize, const M: usize> {
    Small(SmallVec<[(K, V); N]>),
    Large(HashMap<K, V>),
}
A hash map optimized for small sizes, with a small size optimization for up to N entries and then a vector for up to M and then finally falling back to a real hash map after M.

The inline and heap based vectors use linear scans, which is faster than hashing as long as the map is small.

Variants



Small(SmallVec<[(K, V); N]>)



Large(HashMap<K, V>)

Implementations

Source

impl<K: Eq + Hash, V, const N: usize, const M: usize> SmallHashMap<K, V, N, M>

pub fn new() -> Self

pub fn insert(&mut self, key: K, value: V) -> Option<V>

Inserts the association key -> value into the map, returning the previous value for key, if any.

pub fn get_or_insert(&mut self, key: K, or_insert: impl FnOnce() -> V) -> &mut V

Returns either the existing value for key or inserts into key using or_insert.

pub fn remove(&mut self, key: &K) -> Option<V>

pub fn clear(&mut self)

Clears all entries from the map.

pub fn len(&self) -> usize

Returns the number of entries in the map.

pub fn is_empty(&self) -> bool

Returns whether the map is empty.

pub fn iter(&self) -> impl ExactSizeIterator<Item = (&K, &V)>

Returns an iterator over all the key-value pairs in the map.

pub fn keys(&self) -> impl ExactSizeIterator<Item = &K>

Returns an iterator over all the keys in the map.

pub fn values(&self) -> impl ExactSizeIterator<Item = &V>

Returns an iterator over all the values in the map.

pub fn contains_key(&self, key: &K) -> bool

Returns whether key is in the map.

pub fn get(&self, key: &K) -> Option<&V>

Returns the value for key, if any.

pub fn get_mut(&mut self, key: &K) -> Option<&mut V>

Returns the value for key, mutably, if any.