Enums
- Small
Hash Map - A hash map optimized for small sizes,
with a small size optimization for up to
Nentries and then a vector for up toMand then finally falling back to a real hash map afterM.
N entries
and then a vector for up to M
and then finally falling back to a real hash map after M.