pub enum SmallHashMap<K: Eq + Hash, V, const N: usize, const M: usize> {
Small(SmallVec<[(K, V); N]>),
Large(HashMap<K, V>),
}Expand description
A hash map optimized for small sizes,
with a small size optimization for up to N entries
and then a vector for up to M
and then finally falling back to a real hash map after M.
The inline and heap based vectors use linear scans, which is faster than hashing as long as the map is small.
Variants
Implementations
Sourceimpl<K: Eq + Hash, V, const N: usize, const M: usize> SmallHashMap<K, V, N, M>
impl<K: Eq + Hash, V, const N: usize, const M: usize> SmallHashMap<K, V, N, M>
pub fn new() -> Self
Sourcepub fn insert(&mut self, key: K, value: V) -> Option<V>
pub fn insert(&mut self, key: K, value: V) -> Option<V>
Inserts the association key -> value into the map,
returning the previous value for key, if any.
Sourcepub fn get_or_insert(&mut self, key: K, or_insert: impl FnOnce() -> V) -> &mut V
pub fn get_or_insert(&mut self, key: K, or_insert: impl FnOnce() -> V) -> &mut V
Returns either the existing value for key
or inserts into key using or_insert.
pub fn remove(&mut self, key: &K) -> Option<V>
Sourcepub fn iter(&self) -> impl ExactSizeIterator<Item = (&K, &V)>
pub fn iter(&self) -> impl ExactSizeIterator<Item = (&K, &V)>
Returns an iterator over all the key-value pairs in the map.
Sourcepub fn keys(&self) -> impl ExactSizeIterator<Item = &K>
pub fn keys(&self) -> impl ExactSizeIterator<Item = &K>
Returns an iterator over all the keys in the map.
Sourcepub fn values(&self) -> impl ExactSizeIterator<Item = &V>
pub fn values(&self) -> impl ExactSizeIterator<Item = &V>
Returns an iterator over all the values in the map.
Sourcepub fn contains_key(&self, key: &K) -> bool
pub fn contains_key(&self, key: &K) -> bool
Returns whether key is in the map.